function G=ttdG1d(t,gamma,delta)

% USAGE: G = ttdG1d(t,gamma,delta)
% Returns the TTD of the 1-d advection diffusion equation at time 
% t. G is defined in terms of its first (gamma) and second moments 
% (delta^2) respectively:
% gamma = Integral[t*G(t)dt,{0,Inf}]
% delta^2 = (1/2)*Integral[(t-gamma)^2*G(t)dt,{0,Inf}]

% Samar Khatiwala (spk@ldeo.columbia.edu)

% SPK 3/2/06: Cleaned up code and modified expression for G to be 
%             consistent with definition of delta used by others.

warning off

G=sqrt((gamma^3)./(4*pi*(delta^2)*(t.^3))).*exp(-gamma*((t-gamma).^2)./(4*(delta^2)*t));
it=find(t<=0);
G(it)=0;
